@@ -65,11 +65,17 @@ class BaseProduct(BaseModel, ABC):
 
     @classmethod
     def by_sku(cls, sku: str) -> "MinProduct":
-        products = cls.all(filter=f"Sku eq '{sku}'")
+        escaped_sku = cls.escape_filter_value(sku)
+        products = cls.all(filter=f"Sku eq '{escaped_sku}'")
         if not products:
             raise ValueError(f"Product with SKU {sku} not found")
         return products[0]
 
+    @classmethod
+    def escape_filter_value(cls, value: str) -> str:
+        """Escapes special characters in filter values for the ChannelAdvisor API."""
+        return value.replace("'", "''")
+
     @classmethod
     def search_by_sku(cls, sku: str, limit: int = None, include_children: bool = False) -> List["MinProduct"]:
         """We have to check each page for the sku because the API doesn't support fuzzy search"""
@@ -246,7 +252,15 @@ class MinProduct(BaseProduct):
         "5) Maintain brand/model name consistency with title",
     )
     short_description: Optional[str] = Field(
-        None, alias="ShortDescription", description="Short description for SEO. Max length 300 characters."
+        None,
+        alias="ShortDescription",
+        description="Short text only description for SEO."
+        "1) Remove ™, © and ® symbols, "
+        "2) Do not use any html markup, "
+        "3) Do not use any urls, "
+        "4) Maintain brand/model name consistency with title"
+        "5) Keep length under 150 characters",
+        max_length=300,  # Leaving this at 300 to be safe so that importing existing products doesnt break
     )
     asin: Optional[str] = Field(
         None,
